'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (options) {
  const config = (0, _config2.default)(options);
  const app = (0, _koa2.default)();

  app.use(function* injectConfig(next) {
    this.__defineGetter__('config', () => {
      return (0, _config2.default)();
    });
    yield* next;
  });

  app.use((0, _koaBodyparser2.default)());
  app.use((0, _koaLogger2.default)());

  /** Set public path, for css/js/images **/
  app.use((0, _koaStatic2.default)(config.staticPath, {
    maxage: config.debug ? 0 : 60 * 60 * 24 * 7
  }));

  /** Sessions **/
  app.keys = config.keys;
  app.use((0, _koaGenericSession2.default)(config.session, app));

  /** I18n **/
  const i18n = new _i18n2.default(config.messages);

  app.use(function* injectI18n(next) {
    if (this.query.locale) {
      this.session.locale = this.query.locale;
    }
    i18n.setLocale(this.session.locale);
    yield* next;
  });

  /** View & i18n **/
  app.use((0, _koaView2.default)(config.viewPath, {
    noCache: config.debug,
    globals: {
      pagination: _util.pagination,
      __: function __(key) {
        return i18n.message(key);
      }
    }
  }));

  /** ORM **/
  app.orm = (0, _koaOrm2.default)(config.orm);
  app.use(app.orm.middleware);

  /** CSRF */
  (0, _koaCsrf2.default)(app);

  /** Middlewares **/
  (0, _error2.default)(app);
  (0, _flash2.default)(app);
  (0, _mail2.default)(app, config.mail);

  /** Router **/
  (0, _routes2.default)(app, config);

  return app;
};

var _koa = require('koa');

var _koa2 = _interopRequireDefault(_koa);

var _koaView = require('koa-view');

var _koaView2 = _interopRequireDefault(_koaView);

var _koaBodyparser = require('koa-bodyparser');

var _koaBodyparser2 = _interopRequireDefault(_koaBodyparser);

var _koaGenericSession = require('koa-generic-session');

var _koaGenericSession2 = _interopRequireDefault(_koaGenericSession);

var _koaLogger = require('koa-logger');

var _koaLogger2 = _interopRequireDefault(_koaLogger);

var _koaStatic = require('koa-static');

var _koaStatic2 = _interopRequireDefault(_koaStatic);

var _koaCsrf = require('koa-csrf');

var _koaCsrf2 = _interopRequireDefault(_koaCsrf);

var _koaOrm = require('koa-orm');

var _koaOrm2 = _interopRequireDefault(_koaOrm);

var _i18n = require('./i18n');

var _i18n2 = _interopRequireDefault(_i18n);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

var _routes = require('./routes');

var _routes2 = _interopRequireDefault(_routes);

var _error = require('./middlewares/error');

var _error2 = _interopRequireDefault(_error);

var _flash = require('./middlewares/flash');

var _flash2 = _interopRequireDefault(_flash);

var _mail = require('./middlewares/mail');

var _mail2 = _interopRequireDefault(_mail);

var _util = require('./util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = exports['default'];