'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = routes;

var _koaRouter = require('koa-router');

var _koaRouter2 = _interopRequireDefault(_koaRouter);

var _oauth = require('./oauth');

var _oauth2 = _interopRequireDefault(_oauth);

var _user = require('./controllers/user');

var user = _interopRequireWildcard(_user);

var _admin = require('./controllers/admin');

var admin = _interopRequireWildcard(_admin);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function* csrf(next) {
  this.assertCSRF(this.request.body);
  yield next;
}

function routes(app, config) {
  const R = config.routes;
  const oauth = (0, _oauth2.default)(config);
  const router = (0, _koaRouter2.default)();

  router.get(R.home, user.checkLogin, user.home);

  // Login & Logout
  router.get(R.login, user.login);
  router.get(R.logout, user.logout);
  router.post(R.send_token, user.sendToken);
  router.post(R.session, csrf, user.session);

  // Reset password
  router.get(R.password_reset, user.passwordResetPage);
  router.post(R.password_reset, csrf, user.passwordReset);

  // Change password
  router.get(R.password_change, user.passwordChangePage);
  router.post(R.password_change, csrf, user.passwordChange);

  // API: get user info
  router.get(R.user, oauth.authenticate, user.getInfo);

  // OAuth
  router.get(R.authorize, user.checkLogin, oauth.authorize);
  router.post(R.access_token, oauth.accessToken);

  // Admin
  router.get(R.admin.users, admin.checkLogin, admin.userList);
  router.post(R.admin.search_user, admin.checkLogin, admin.searchUser);
  router.get(R.admin.clients, admin.checkLogin, admin.clientList);
  router.post(R.admin.send_totp, csrf, admin.checkLogin, admin.sendTotp);
  router.post(R.admin.add_client, csrf, admin.checkLogin, admin.addClient);
  router.post(R.admin.generate_secret, csrf, admin.checkLogin, admin.generateSecret);
  router.get(R.admin.roles, admin.checkLogin, admin.roleList);
  router.post(R.admin.add_role, csrf, admin.checkLogin, admin.addRole);
  router.post(R.admin.delete_role, csrf, admin.checkLogin, admin.deleteRole);

  app.use(function* injectParams(next) {
    this.state._csrf = this.csrf;
    this.state.logo = config.logo;
    this.state.favicon = config.favicon;
    this._routes = this.state._routes = R;
    yield* next;
  });
  app.use(router.routes());
  app.use(router.allowedMethods());
}
module.exports = exports['default'];