'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pagination = pagination;
exports.makeSalt = makeSalt;
exports.encrypt = encrypt;
exports.checkURI = checkURI;
exports.generateToken = generateToken;
exports.buildURI = buildURI;
exports.encodeKey = encodeKey;
exports.totpURI = totpURI;
exports.totpImage = totpImage;

var _crypto = require('crypto');

var _crypto2 = _interopRequireDefault(_crypto);

var _thirtyTwo = require('thirty-two');

var _thirtyTwo2 = _interopRequireDefault(_thirtyTwo);

var _qrImage = require('qr-image');

var _qrImage2 = _interopRequireDefault(_qrImage);

var _url = require('url');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function pagination(cur, total, link, half = 2) {
  if (total <= 1) return '';

  let left = Math.max(1, cur - half);
  let right = Math.min(left + half * 2, total);

  if (total - cur <= half) {
    left = Math.max(1, total - half * 2);
  }
  const temp = ['<ul class="pagination">'];
  if (cur > 1) {
    temp.push(`<li><a href="${link(cur - 1)}">&laquo;</a></li>`);
  }

  for (let i = left; i <= right; i++) {
    temp.push(`<li class="${cur === i ? 'active' : ''}"><a href="${link(i)}">${i}</a></li>`);
  }
  if (cur !== total) {
    temp.push(`<li><a href="${link(cur + 1)}">&raquo;</a></li>`);
  }
  temp.push('</ul>');
  return temp.join('');
}

function makeSalt() {
  return Math.round(new Date().valueOf() * Math.random()) + '';
}

function encrypt(pass, salt) {
  if (!pass) return null;
  return _crypto2.default.createHmac('sha1', salt).update(pass).digest('hex');
}

function checkURI(base, checked) {
  let url1 = (0, _url.parse)(base, false, true);
  let url2 = (0, _url.parse)(checked, false, true);

  url1.port = url1.port || 80;
  url2.port = url2.port || 80;
  url1.pathname = url1.pathname || '/';
  url2.pathname = url2.pathname || '/';

  return url1.hostname === url2.hostname && url1.port === url2.port && url2.pathname.indexOf(url1.pathname) === 0;
}

function generateToken() {
  let buffer = _crypto2.default.randomBytes(256);
  return _crypto2.default.createHash('sha1').update(buffer).digest('hex');
}

function buildURI(uri, query) {
  let obj = (0, _url.parse)(uri, true);
  Object.assign(obj.query, query);
  delete obj.search;
  return (0, _url.format)(obj);
}

function encodeKey(key) {
  return _thirtyTwo2.default.encode(key).toString().replace(/=/g, '');
}

function totpURI(user, key) {
  return `otpauth://totp/${user}?secret=${encodeKey(key)}`;
}

function totpImage(user, key) {
  return _qrImage2.default.imageSync(totpURI(user, key), 'H');
}